pro output_productmap, colorimage,range,xparameter,outputname, $
	               allAnnote,valid_values,                 $
		       rplot,gplot,bplot,                      $
 		       psdisplay=psdisplay,jpeg=jpeg,          $
		       screen=screen,add=add,tiff=tiff,notation=notation

; IDL routine
;
;  output_productmap.pro v 0.5
;  
;    Outputs an 8-bit image to a jpeg or a ps file 
;
; v 0.5 notes: really needs work. I'd like to avoid using vector fonts
;	       in the jpeg output someday.  Image sizing/location in the
;	       jpeg output is funny sometimes (xsize/ysize calculated from the 
;              display variables is sometimes wrong. Huh. wierd.) Notation in
;              the ps output isn't always located properly.
;              This code needs more abstraction and better documentation.
;              The option to output to the screen is not used yet.
;              This routine is really not 100% bug proof.  Yes well, even 
;              more so than the rest of the code.
;
; Keywords:
;    /psdisplay    output a ps files
;    /jpeg         output a jpeg file
;    /tiff         output a tiff file
;    /add          not currently used (development only)
;    /notation     turns on grids and continents
;    /screen       not implemented
;
; Input:
;
;    colorimage  byte array    3 channel byte image data of the form [n,m,3] where 3rd index is r,g,b
;    range        byte vector   channel max and mins
;    xparameter   real array    image positioning values for locating image in the display device
;    outputname   string        output file name for image
;    descriptions string	the annotations to use on colorbar
;    valid_values int array	valid values of the data
;    r,g,bplot    int arrays    the user defined color scheme for plot
; Output:
;    none
;
; Required routines:  
;    finish_map.pro   draws some map grids and so forth on display device 
;
; Developer
;  v .5         Eric Moody moody@climate.gsfc.nasa.gov
;               Mark Gray mag@climate.gsfc.nasa.gov
;               SM&A - SSG
;               MODIS - Atmosphere Group

; Initialize the new color scheme for the bit field:
r = intarr(255)
g = intarr(255)
b = intarr(255)

;Set the user defined color scheme into r,g,b:
numcolors = size(rplot)
for icnt = 0, numcolors[1]-1 do begin
    r[icnt] = rplot[icnt]
    g[icnt] = gplot[icnt]
    b[icnt] = bplot[icnt]
endfor

;Set the 99th spot to orange (used for lines and notation)
r[99] = 255
g[99] = 185
b[99] = 100

;Set the 98th spot to white:
r[98] = 255
g[98] = 255
b[98] = 255

;Load in the color bar, shifting it by one so that the 0 spot is black.
tvlct, r, g, b, 1


if  keyword_set(psdisplay) or keyword_set(screen) then begin

   ;Load in the offsets and size:
   xoffset = xparameter(0)
   yoffset = xparameter(1)
   xsize   = xparameter(2)
   ysize   = xparameter(3) 

   ;Plot the image and add lat/lon lines and continental boundaries:
   tv, colorimage, xoffset, yoffset, xsize = xsize, ysize = ysize
   finish_map,/ps

   ;Determine the number of valid values, and thus the number of descripters:
   numValids = size(valid_values)
   numValids = numValids[1]
 
   ;Create the color array which includes colors for all descripters:
   colors = intarr(numValids)
   colors = IndGen(numValids) + 1  ;Add one since indgen starts with 0

   ;plot color bar, including all of the valid categories.
   color_key, colors = colors, labels = allAnnote, xoff=3

endif

if keyword_set(psdisplay) then begin
  Device,/close
  set_plot,'x'
endif

if keyword_set(add) then begin
   print,'adding data'
   xoffset = xparameter(0)
   yoffset = xparameter(1)
   xsize = xparameter(2)
   ysize = xparameter(3)
   print,'writing output image data'
   tv, bytscl(colorimage,min=range[0],max=range[1]), xoffset, $
                yoffset, $
                xsize = xsize,  $
                ysize = ysize, $
                true=3          
endif

if keyword_set(jpeg) or keyword_set(tiff) then begin
   print, 'jpeg and tiff option not implemented'
endif

if keyword_set(screen) then begin
   print, 'screen option not implemented'
endif

end
