pro driver

; IDL routine
;
; driver.pro v 1.0
;
; driver.pro is the driver routine for producing an HDF file that 
;  contains individual bit flags extracted from a byte array.  This
;  particular driver has been taylored for outputing MOD06 QA flags, 
;  but can serve as a template/example for other bit flag extractions.
;  This code assumes that the input MOD06 L2QA follows the MOD06 L2QA Plan.
;
; This code produces an output HDF file, whose contents can be plotted using
;   the BitMapper code.
;
;
; Input: 
;		none
; 
; Output:
;    		none
;
; Required routines:
;    l2qa_extracter
;
; Developer
;  v 1.0  03/20/2001
;           	Eric Moody moody@climate.gsfc.nasa.gov
;               Emergent IT
;               MODIS - Atmosphere Group
;

;*************************************************************************
;Specify the year, day and time of the granule.
;Ex. for year 2000, day 95, time 4:30,
; year = '2000'
; day  = '095'
; time = '0430' 
;*************************************************************************
year = '2000'
day  = '336'
time = '0845'


;*************************************************************************
;Specify the output file name and path:
;  Note:  Specify the full path
;  The default is in the current directory's output subdirectory
;*************************************************************************
;For general runs:
L2QAHDFFileName = './output/L2QAflags.'+year+'.'+day+'.'+time+'.hdf'


;*************************************************************************
;Specify the path where the MOD06, cloud properties, file resides:
;  Note:  Specify the full path
;*************************************************************************
;MODAPS processed directory on windhoek:
fullpath = '/archive/MOD06/'+year+'/'+day+'/'


;*************************************************************************
;Find the MOD06 file for the specified year, day, and time
;*************************************************************************
;MODAPs processed files:
file_spec = fullpath+'MOD06*'+year+day+'.'+time+'*hdf'
result = FINDFILE(file_spec)
MOD06FileName = strcompress(result(0))


;*************************************************************************
;Call the code:
;*************************************************************************
l2qa_extracter, year, day, time, MOD06FileName, L2QAHDFFileName

end
